import type React from "react";
import { useEffect, useRef, useState } from "react";

interface DebounceProps {
	debouceDelay: number;
	onDebounce: (value: string) => void;
}

type DebouceInputProps = DebounceProps &
	React.InputHTMLAttributes<HTMLInputElement>;

export default function DebounceInput(props: DebouceInputProps) {
	const [value, setValue] = useState<string>("");

	const debounceTimeout = useRef<number | null>(null);

	useEffect(() => {
		if (typeof props.value === "string") {
			setValue(props.value);
		} else {
			setValue("");
		}
	}, [props.value]);

	function handleOnChange(e: React.ChangeEvent<HTMLInputElement>) {
		if (debounceTimeout.current) {
			clearTimeout(debounceTimeout.current);
		}

		setValue(e.target.value);

		debounceTimeout.current = setTimeout(
			() => props.onDebounce(e.target.value),
			props.debouceDelay,
		);

		if (props.onChange) {
			props.onChange(e);
		}
	}

	const inputAttr = {
		...props,
		debouceDelay: undefined,
		onDebounce: undefined,
	};

	return (
		<input
			className={props.className}
			placeholder={props.placeholder}
			id={props.id}
			type="text"
			value={value}
			onChange={handleOnChange}
			onKeyDown={props.onKeyDown}
		/>
	);
}
