import { useState } from "react";
import LoginForm, { type LoginFormValue } from "./LoginForm";

export default function LoginFormData() {
	const [loading, setLoading] = useState<boolean>(false);

	function handleOnFormSubmit(data: LoginFormValue) {
		const searchParams = new URLSearchParams(window.location.search);
		setLoading(true);

		fetch("/api/accounts/login", {
			method: "POST",
			body: JSON.stringify(data),
			credentials: "include",
			headers: {
				Accept: "application/json",
				"Content-Type": "application/json",
			},
		})
			.then((res) => res.json())
			.then(() => {
				window.location.href = searchParams.get("redirect") || "/home";
			})
			.catch((err) => console.log(err))
			.finally(() => setLoading(false));
	}

	return <LoginForm onSubmit={handleOnFormSubmit} disabled={loading} />;
}
